@@ -1,3 +1,4 @@
+import sys
 from .conf import settings
 from .types import Rule
 from .system import Path
@@ -14,21 +15,37 @@ def get_loaded_rules(rules_paths):
     for path in rules_paths:
         if path.name != '__init__.py':
             rule = Rule.from_path(path)
-            if rule.is_enabled:
+            if rule and rule.is_enabled:
                 yield rule
 
 
+def get_rules_import_paths():
+    """Yields all rules import paths.
+
+    :rtype: Iterable[Path]
+
+    """
+    # Bundled rules:
+    yield Path(__file__).parent.joinpath('rules')
+    # Rules defined by user:
+    yield settings.user_dir.joinpath('rules')
+    # Packages with third-party rules:
+    for path in sys.path:
+        for contrib_module in Path(path).glob('thefuck_contrib_*'):
+            contrib_rules = contrib_module.joinpath('rules')
+            if contrib_rules.is_dir():
+                yield contrib_rules
+
+
 def get_rules():
     """Returns all enabled rules.
 
     :rtype: [Rule]
 
     """
-    bundled = Path(__file__).parent \
-        .joinpath('rules') \
-        .glob('*.py')
-    user = settings.user_dir.joinpath('rules').glob('*.py')
-    return sorted(get_loaded_rules(sorted(bundled) + sorted(user)),
+    paths = [rule_path for path in get_rules_import_paths()
+             for rule_path in sorted(path.glob('*.py'))]
+    return sorted(get_loaded_rules(paths),
                   key=lambda rule: rule.priority)
 
 
@@ -54,7 +71,7 @@ def organize_commands(corrected_commands):
         without_duplicates,
         key=lambda corrected_command: corrected_command.priority)
 
-    logs.debug('Corrected commands: '.format(
+    logs.debug(u'Corrected commands: {}'.format(
         ', '.join(u'{}'.format(cmd) for cmd in [first_command] + sorted_commands)))
 
     for command in sorted_commands:
