@@ -1,9 +1,8 @@
-from imp import load_source
 import os
 import sys
 from . import logs
 from .shells import shell
-from .conf import settings
+from .conf import settings, load_source
 from .const import DEFAULT_PRIORITY, ALL_ENABLED
 from .exceptions import EmptyCommand
 from .utils import get_alias, format_raw_script
@@ -13,17 +12,25 @@ from .output_readers import get_output
 class Command(object):
     """Command that should be fixed."""
 
-    def __init__(self, script, stdout, stderr):
+    def __init__(self, script, output):
         """Initializes command with given values.
 
         :type script: basestring
-        :type stdout: basestring
-        :type stderr: basestring
+        :type output: basestring
 
         """
         self.script = script
-        self.stdout = stdout
-        self.stderr = stderr
+        self.output = output
+
+    @property
+    def stdout(self):
+        logs.warn('`stdout` is deprecated, please use `output` instead')
+        return self.output
+
+    @property
+    def stderr(self):
+        logs.warn('`stderr` is deprecated, please use `output` instead')
+        return self.output
 
     @property
     def script_parts(self):
@@ -39,14 +46,13 @@ class Command(object):
 
     def __eq__(self, other):
         if isinstance(other, Command):
-            return ((self.script, self.stdout, self.stderr)
-                    == (other.script, other.stdout, other.stderr))
+            return (self.script, self.output) == (other.script, other.output)
         else:
             return False
 
     def __repr__(self):
-        return u'Command(script={}, stdout={}, stderr={})'.format(
-            self.script, self.stdout, self.stderr)
+        return u'Command(script={}, output={})'.format(
+            self.script, self.output)
 
     def update(self, **kwargs):
         """Returns new command with replaced fields.
@@ -55,8 +61,7 @@ class Command(object):
 
         """
         kwargs.setdefault('script', self.script)
-        kwargs.setdefault('stdout', self.stdout)
-        kwargs.setdefault('stderr', self.stderr)
+        kwargs.setdefault('output', self.output)
         return Command(**kwargs)
 
     @classmethod
@@ -73,8 +78,8 @@ class Command(object):
             raise EmptyCommand
 
         expanded = shell.from_shell(script)
-        stdout, stderr = get_output(script, expanded)
-        return cls(expanded, stdout, stderr)
+        output = get_output(script, expanded)
+        return cls(expanded, output)
 
 
 class Rule(object):
@@ -116,7 +121,7 @@ class Rule(object):
     def __repr__(self):
         return 'Rule(name={}, match={}, get_new_command={}, ' \
                'enabled_by_default={}, side_effect={}, ' \
-               'priority={}, requires_output)'.format(
+               'priority={}, requires_output={})'.format(
                    self.name, self.match, self.get_new_command,
                    self.enabled_by_default, self.side_effect,
                    self.priority, self.requires_output)
@@ -130,9 +135,16 @@ class Rule(object):
 
         """
         name = path.name[:-3]
+        if name in settings.exclude_rules:
+            logs.debug(u'Ignoring excluded rule: {}'.format(name))
+            return
         with logs.debug_time(u'Importing rule: {};'.format(name)):
-            rule_module = load_source(name, str(path))
-            priority = getattr(rule_module, 'priority', DEFAULT_PRIORITY)
+            try:
+                rule_module = load_source(name, str(path))
+            except Exception:
+                logs.exception(u"Rule {} failed to load".format(name), sys.exc_info())
+                return
+        priority = getattr(rule_module, 'priority', DEFAULT_PRIORITY)
         return cls(name, rule_module.match,
                    rule_module.get_new_command,
                    getattr(rule_module, 'enabled_by_default', True),
@@ -147,14 +159,11 @@ class Rule(object):
         :rtype: bool
 
         """
-        if self.name in settings.exclude_rules:
-            return False
-        elif self.name in settings.rules:
-            return True
-        elif self.enabled_by_default and ALL_ENABLED in settings.rules:
-            return True
-        else:
-            return False
+        return (
+            self.name in settings.rules
+            or self.enabled_by_default
+            and ALL_ENABLED in settings.rules
+        )
 
     def is_match(self, command):
         """Returns `True` if rule matches the command.
@@ -163,9 +172,7 @@ class Rule(object):
         :rtype: bool
 
         """
-        script_only = command.stdout is None and command.stderr is None
-
-        if script_only and self.requires_output:
+        if command.output is None and self.requires_output:
             return False
 
         try:
@@ -251,4 +258,4 @@ class CorrectedCommand(object):
         logs.debug(u'PYTHONIOENCODING: {}'.format(
             os.environ.get('PYTHONIOENCODING', '!!not-set!!')))
 
-        print(self._get_script())
+        sys.stdout.write(self._get_script())
